<?php

declare(strict_types=1);


namespace App\Exchanges\Kuna;


use Nyholm\Psr7\Request;
use Psr\Http\Client\ClientInterface;

class KunaApiExecutor
{

    public const API_BASE_URL = 'https://api.kuna.io';

    private ClientInterface $client;
    private KunaSigner $signer;

    public function __construct(
        ClientInterface $client,
        KunaSigner $signer
    )
    {
        $this->client = $client;
        $this->signer = $signer;
    }

    public function getMarkets(): array
    {
        $response = $this
            ->client
            ->sendRequest(
                new Request(
                    'GET',
                    self::API_BASE_URL . '/v3/markets'
                )
            );

        return json_decode((string)$response->getBody(), true);
    }

    public function getBook(string $symbol): array
    {
        $response = $this
            ->client
            ->sendRequest(
                new Request(
                    'GET',
                    self::API_BASE_URL . '/v3/book/' . $symbol
                )
            );

        return json_decode((string)$response->getBody(), true);
    }
}