<?php

declare(strict_types=1);


namespace App\Exchanges\Kuna;


use App\Exchanges\MarketInterface;
use App\Utils\Money\Currency;
use App\Utils\Money\CurrencyPair;
use App\Utils\Money\Money;
use App\Utils\Order\Book\OrderBook;
use App\Utils\Order\Order;

class KunaMarket implements MarketInterface
{

    private KunaApiExecutor $apiExecutor;
    private CurrencyPair $currencyPair;
    private string $id;


    public static function createFromApiData(
        array $marketData,
        KunaApiExecutor $apiExecutor
    ): self
    {
        return new self(
            $apiExecutor,
            new CurrencyPair(
                new Currency($marketData['base_unit'], (int)$marketData['base_precision']),
                new Currency($marketData['quote_unit'], (int)$marketData['quote_precision']),
            ),
            $marketData['id']
        );
    }

    public function __construct(
        KunaApiExecutor $apiExecutor,
        CurrencyPair $currencyPair,
        string $id
    )
    {
        $this->apiExecutor = $apiExecutor;
        $this->currencyPair = $currencyPair;
        $this->id = $id;
    }

    public function getPair(): CurrencyPair
    {
        return $this->currencyPair;
    }

    public function getOrderBook(): OrderBook
    {
        $asks = [];
        $bids = [];

        foreach ($this->apiExecutor->getBook($this->id) as $orderData) {
            $order = new Order(
                new Money((string)$orderData[0], $this->currencyPair->getQuote()),
                new Money((string)abs($orderData[1]), $this->currencyPair->getBase()),
            );

            $ordersCount = $orderData[2];
            while ($ordersCount) {
                if ($orderData[1] > 0) {
                    $bids[] = clone $order;
                } else {
                    $asks[] = clone $order;
                }
                $ordersCount--;
            }
        }

        return new OrderBook($bids, $asks);
    }
}